# dispy: Node Information

IP Address |
Name |
CPUs Managed by dispy |
Available CPU | Unknown
Available Memory | Unknown
Available Swap Space | Unknown
Available Disk Space | Unknown
Jobs Done |
CPU Time Used Sec |
CPU Time Sec / Job |
Data Sent |
Data Received |
Last Update |

Jobs Running
| Cluster | Job ID | Arguments | Started At
--- | --- | --- | --- | ---

Terminate Selected Jobs :

Update Interval Seconds : |
Name or IP of Node to Show : |

Node Action :